pub struct PlaysToken<Player: Model, Owner: Model, Players> { /* private fields */ }Expand description
A playing-fact token branded by player, role owner, and accepted-player enum.
Implementations
Sourceimpl<Player: Model, Owner: Model, Players> PlaysToken<Player, Owner, Players>
impl<Player: Model, Owner: Model, Players> PlaysToken<Player, Owner, Players>
Sourcepub const fn new(
plays_id_json: &'static str,
metadata_json: &'static str,
) -> Self
pub const fn new( plays_id_json: &'static str, metadata_json: &'static str, ) -> Self
Construct a token from canonical playing identity and metadata JSON.
Sourcepub const fn plays_id_json(self) -> &'static str
pub const fn plays_id_json(self) -> &'static str
Return the token’s canonical playing identity JSON.
Sourcepub const fn metadata_json(self) -> &'static str
pub const fn metadata_json(self) -> &'static str
Return the token’s canonical metadata JSON.