pub struct Sequence<T> { /* private fields */ }Expand description
A sequence checked against its exact resolved cardinality.
Implementations
Sourceimpl<T> Sequence<T>
impl<T> Sequence<T>
Sourcepub fn try_new(
values: Vec<T>,
cardinality: Cardinality,
path: &ValidationPath,
) -> Result<Self, ValidationError>
pub fn try_new( values: Vec<T>, cardinality: Cardinality, path: &ValidationPath, ) -> Result<Self, ValidationError>
Validate and wrap a sequence against its resolved cardinality.
Errors
Returns a stable validation error when the length cannot be represented
or falls outside cardinality.
Sourcepub const fn cardinality(&self) -> Cardinality
pub const fn cardinality(&self) -> Cardinality
Return the cardinality against which this sequence was validated.