ModelFamily

Trait ModelFamily 

pub trait ModelFamily: Sealed {
    type Root: ThingModel;
    type Schema: Schema;

    // Required method
    fn iid(&self) -> &str;
}
A closed subtype family enum representing a concrete descendant closure for a root Root.

Required Associated Types

type Root: ThingModel

The generated root model whose concrete descendants form this family.

type Schema: Schema

The generated schema that owns the family.

Required Methods

fn iid(&self) -> &str

Return the canonical IID of the materialized family member.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors