NumericValued

Trait NumericValued 

pub trait NumericValued {
    type Reduced;
}
Marker for generated attribute values whose canonical domain admits numeric reduction, carrying the canonical reduced scalar domain.

Required Associated Types

type Reduced

The canonical scalar domain of domain-preserving reductions.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl NumericValued for i64

Implementors