RoleTokenCompatible

Trait RoleTokenCompatible 

pub trait RoleTokenCompatible<Owner: RelationModel, Players>: RelationModel { }
Positive generated evidence that one role token is active on a relation.

Unlike nominal inheritance, this relation is intentionally subtractive: generated specializing relations do not implement compatibility for the specialized-away ancestor role.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors