pub trait TextValued { }Expand description
Marker for generated attribute values whose canonical domain is text.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait TextValued { }Marker for generated attribute values whose canonical domain is text.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".