AggregateTuple

Trait AggregateTuple 

pub trait AggregateTuple<S: Schema>: Sealed<S> {
    type Output;
}
Sealed tuple of typed reducer terms through the sixteen-slot ceiling.

Required Associated Types

type Output

The typed tuple output decoded from one reduction row.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S: Schema, A: ReducedOutput, B: ReducedOutput, C: ReducedOutput, D: ReducedOutput, E: ReducedOutput, F: ReducedOutput, G: ReducedOutput, H: ReducedOutput> AggregateTuple<S> for (Agg<S, A>, Agg<S, B>, Agg<S, C>, Agg<S, D>, Agg<S, E>, Agg<S, F>, Agg<S, G>, Agg<S, H>)

Source

impl<S: Schema, A: ReducedOutput, B: ReducedOutput, C: ReducedOutput, D: ReducedOutput, E: ReducedOutput, F: ReducedOutput, G: ReducedOutput> AggregateTuple<S> for (Agg<S, A>, Agg<S, B>, Agg<S, C>, Agg<S, D>, Agg<S, E>, Agg<S, F>, Agg<S, G>)

Source

impl<S: Schema, A: ReducedOutput, B: ReducedOutput, C: ReducedOutput, D: ReducedOutput, E: ReducedOutput, F: ReducedOutput> AggregateTuple<S> for (Agg<S, A>, Agg<S, B>, Agg<S, C>, Agg<S, D>, Agg<S, E>, Agg<S, F>)

Source

impl<S: Schema, A: ReducedOutput, B: ReducedOutput, C: ReducedOutput, D: ReducedOutput, E: ReducedOutput> AggregateTuple<S> for (Agg<S, A>, Agg<S, B>, Agg<S, C>, Agg<S, D>, Agg<S, E>)

Source

impl<S: Schema, A: ReducedOutput, B: ReducedOutput, C: ReducedOutput, D: ReducedOutput> AggregateTuple<S> for (Agg<S, A>, Agg<S, B>, Agg<S, C>, Agg<S, D>)

Source

impl<S: Schema, A: ReducedOutput, B: ReducedOutput, C: ReducedOutput> AggregateTuple<S> for (Agg<S, A>, Agg<S, B>, Agg<S, C>)

Source

impl<S: Schema, A: ReducedOutput, B: ReducedOutput> AggregateTuple<S> for (Agg<S, A>, Agg<S, B>)

Source

impl<S: Schema, A: ReducedOutput> AggregateTuple<S> for (Agg<S, A>,)

Implementors