#[non_exhaustive]pub enum ErrorPathSegment {
Show 13 variants
Argument(String),
Field(String),
Index(u64),
Identifier(String),
Query(QueryDiagnosticPathKind),
QueryBinding(u16),
QueryField {
owner: String,
name: String,
},
QueryRole {
owner: String,
name: String,
},
QueryRoleEdge(u16),
QueryOutputSlot(u64),
QueryOutputName(String),
ContractField(String),
ContractIdentity(String),
}Expand description
One typed segment from a structured engine or remote diagnostic path.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Argument(String)
A named public operation argument.
Field(String)
A named field in the rejected contract.
Index(u64)
An indexed member in the rejected contract.
Identifier(String)
A schema or query identifier.
Query(QueryDiagnosticPathKind)
A structural typed-query request or result location.
QueryBinding(u16)
A plan-local typed-query binding ordinal.
QueryField
A descriptor-qualified binding-facing query field.
Fields
QueryRole
A descriptor-qualified query role.
Fields
QueryRoleEdge(u16)
A plan-local typed-query role-edge ordinal.
QueryOutputSlot(u64)
A zero-based positional query output slot.
QueryOutputName(String)
A declared generated query output member.
ContractField(String)
An object field retained from an authenticated contract diagnostic.
ContractIdentity(String)
An identity retained from an authenticated contract diagnostic.