pub struct MigrationPlan<S: Schema> { /* private fields */ }Expand description
Generated-schema-branded executable migration plan.
Implementations
Sourceimpl<S: Schema> MigrationPlan<S>
impl<S: Schema> MigrationPlan<S>
Confirm that policy and exact approvals granted execution authority.
Sourcepub async fn execute(
&self,
database: &Database<S>,
holder: &str,
) -> Result<MigrationExecutionReport>
pub async fn execute( &self, database: &Database<S>, holder: &str, ) -> Result<MigrationExecutionReport>
Execute this plan through the exact managed database/journal pair.
Sourcepub async fn execute_controlled(
&self,
database: &Database<S>,
holder: &str,
control: &MigrationExecutionControl,
) -> Result<MigrationExecutionReport>
pub async fn execute_controlled( &self, database: &Database<S>, holder: &str, control: &MigrationExecutionControl, ) -> Result<MigrationExecutionReport>
Execute with shared cancellation, absolute deadline, and tightened limits.