pub enum DatabaseCreateOutcome {
Created,
AlreadyExists,
}Expand description
Normalized outcome of creating the database bound to a generated client.
Variants
Created
This operation created the database.
AlreadyExists
The database already existed or a concurrent creator won the race.