pub enum ManagedDatabasePairState {
Absent,
StandaloneManaged,
OwnedPair,
OwnedJournalOrphan,
}Expand description
Read-only state of one exact managed database and reserved journal pair.
Variants
Absent
Neither member exists.
StandaloneManaged
Only a standalone managed database without TypeBridge control state exists.
OwnedPair
Both members exist and the journal owns this exact database and scope.
OwnedJournalOrphan
Only the exact owner-verified journal remains.