pub struct BoundRole<S: Schema, Owner: Model<Schema = S>, Players> { /* private fields */ }Expand description
One generated relation role resolved against one relation binding occurrence.
Implementations
Sourceimpl<S: Schema, Owner: Model<Schema = S>, Players> BoundRole<S, Owner, Players>
impl<S: Schema, Owner: Model<Schema = S>, Players> BoundRole<S, Owner, Players>
Sourcepub fn connects<MP: ThingModel<Schema = S>, ModeP: SelectionMode>(
self,
player: Binding<S, MP, ModeP>,
) -> Predicate<S>where
Players: RolePlayerBinding<MP, ModeP>,
pub fn connects<MP: ThingModel<Schema = S>, ModeP: SelectionMode>(
self,
player: Binding<S, MP, ModeP>,
) -> Predicate<S>where
Players: RolePlayerBinding<MP, ModeP>,
Require this relation role to connect an admitted generated player binding.