pub struct Order<S: Schema> { /* private fields */ }Expand description
One stable public ordering term over a bound field.
Implementations
Sourceimpl<S: Schema> Order<S>
impl<S: Schema> Order<S>
Sourcepub fn missing_first(self) -> Self
pub fn missing_first(self) -> Self
Admit missing keys and place them before all present keys.
Sourcepub fn missing_last(self) -> Self
pub fn missing_last(self) -> Self
Admit missing keys and place them after all present keys.