pub struct RemoteDatabase<S: Schema = Unbound> { /* private fields */ }Expand description
A client-owned remote generated-query database branded by schema S.
Implementations
Sourceimpl RemoteDatabase<Unbound>
impl RemoteDatabase<Unbound>
Sourcepub async fn connect(options: RemoteConnectionOptions) -> Result<Self>
pub async fn connect(options: RemoteConnectionOptions) -> Result<Self>
Fetch and validate one immutable executor advertisement.
Sourcepub fn with_schema<S: Schema>(
self,
schema: SchemaPackage<S>,
) -> Result<RemoteDatabase<S>>
pub fn with_schema<S: Schema>( self, schema: SchemaPackage<S>, ) -> Result<RemoteDatabase<S>>
Verify and bind one generated schema package and its remote authority.
Sourceimpl<S: Schema> RemoteDatabase<S>
impl<S: Schema> RemoteDatabase<S>
Sourcepub fn query(&self) -> Result<QuerySession<'_, S>>
pub fn query(&self) -> Result<QuerySession<'_, S>>
Start one owner-branded query session over this remote executor.
Sourcepub fn query_with_resources(
&self,
resources: QueryExecutionResourceLimits,
cancellation: AnswerCancellation,
) -> Result<QuerySession<'_, S>>
pub fn query_with_resources( &self, resources: QueryExecutionResourceLimits, cancellation: AnswerCancellation, ) -> Result<QuerySession<'_, S>>
Start one remote query session with one common tighten-only resource policy and caller-owned cooperative cancellation signal.