SelectedShape

Trait SelectedShape 

pub trait SelectedShape<S: Schema>: Sealed<S> + Clone {
    type Output;
}
Sealed typed selected-output shape accepted by the one query facade.

Implementations are supplied for one binding, positional tuples through the canonical sixteen-slot ceiling, and derive-backed named rows.

Required Associated Types

type Output

One fully materialized public row.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>, H: SelectedSlot<S>, I: SelectedSlot<S>, J: SelectedSlot<S>, K: SelectedSlot<S>, L: SelectedSlot<S>, M: SelectedSlot<S>, N: SelectedSlot<S>, O: SelectedSlot<S>, P: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>, H: SelectedSlot<S>, I: SelectedSlot<S>, J: SelectedSlot<S>, K: SelectedSlot<S>, L: SelectedSlot<S>, M: SelectedSlot<S>, N: SelectedSlot<S>, O: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>, H: SelectedSlot<S>, I: SelectedSlot<S>, J: SelectedSlot<S>, K: SelectedSlot<S>, L: SelectedSlot<S>, M: SelectedSlot<S>, N: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)

Source

type Output = <(A, B, C, D, E, F, G, H, I, J, K, L, M, N) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>, H: SelectedSlot<S>, I: SelectedSlot<S>, J: SelectedSlot<S>, K: SelectedSlot<S>, L: SelectedSlot<S>, M: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L, M)

Source

type Output = <(A, B, C, D, E, F, G, H, I, J, K, L, M) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>, H: SelectedSlot<S>, I: SelectedSlot<S>, J: SelectedSlot<S>, K: SelectedSlot<S>, L: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

type Output = <(A, B, C, D, E, F, G, H, I, J, K, L) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>, H: SelectedSlot<S>, I: SelectedSlot<S>, J: SelectedSlot<S>, K: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K)

Source

type Output = <(A, B, C, D, E, F, G, H, I, J, K) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>, H: SelectedSlot<S>, I: SelectedSlot<S>, J: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G, H, I, J)

Source

type Output = <(A, B, C, D, E, F, G, H, I, J) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>, H: SelectedSlot<S>, I: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G, H, I)

Source

type Output = <(A, B, C, D, E, F, G, H, I) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>, H: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G, H)

Source

type Output = <(A, B, C, D, E, F, G, H) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>, G: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F, G)

Source

type Output = <(A, B, C, D, E, F, G) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>, F: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E, F)

Source

type Output = <(A, B, C, D, E, F) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>, E: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D, E)

Source

type Output = <(A, B, C, D, E) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>, D: SelectedSlot<S>> SelectedShape<S> for (A, B, C, D)

Source

type Output = <(A, B, C, D) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>, C: SelectedSlot<S>> SelectedShape<S> for (A, B, C)

Source

type Output = <(A, B, C) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>, B: SelectedSlot<S>> SelectedShape<S> for (A, B)

Source

type Output = <(A, B) as SelectedTuple<S>>::Output

Source

impl<S: Schema, A: SelectedSlot<S>> SelectedShape<S> for (A,)

Source

type Output = <(A,) as SelectedTuple<S>>::Output

Implementors

Source

impl<S, Row, Slots> SelectedShape<S> for NamedSelection<S, Row, Slots>
where S: Schema, Slots: SelectedTuple<S>, Row: SelectedRowSpec<Slots::Output>,

Source

type Output = Row

Source

impl<S: Schema, B: Selectable<S>> SelectedShape<S> for B

Source

type Output = <B as Selectable<S>>::Output

Source

impl<S: Schema, B: Selectable<S>> SelectedShape<S> for Collected<S, B>

Source

type Output = Vec<<B as Selectable<S>>::Output>