SingularSelectedShape

Trait SingularSelectedShape 

pub trait SingularSelectedShape<S: Schema>: SelectedShape<S> + Sealed<S> { }
Sealed marker for a selected shape containing singular slots only.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>, H: Selectable<S>, I: Selectable<S>, J: Selectable<S>, K: Selectable<S>, L: Selectable<S>, M: Selectable<S>, N: Selectable<S>, O: Selectable<S>, P: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>, H: Selectable<S>, I: Selectable<S>, J: Selectable<S>, K: Selectable<S>, L: Selectable<S>, M: Selectable<S>, N: Selectable<S>, O: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>, H: Selectable<S>, I: Selectable<S>, J: Selectable<S>, K: Selectable<S>, L: Selectable<S>, M: Selectable<S>, N: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>, H: Selectable<S>, I: Selectable<S>, J: Selectable<S>, K: Selectable<S>, L: Selectable<S>, M: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L, M)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>, H: Selectable<S>, I: Selectable<S>, J: Selectable<S>, K: Selectable<S>, L: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>, H: Selectable<S>, I: Selectable<S>, J: Selectable<S>, K: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G, H, I, J, K)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>, H: Selectable<S>, I: Selectable<S>, J: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G, H, I, J)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>, H: Selectable<S>, I: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G, H, I)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>, H: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G, H)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>, G: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F, G)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>, F: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E, F)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>, E: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D, E)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>, D: Selectable<S>> SingularSelectedShape<S> for (A, B, C, D)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>, C: Selectable<S>> SingularSelectedShape<S> for (A, B, C)

Source

impl<S: Schema, A: Selectable<S>, B: Selectable<S>> SingularSelectedShape<S> for (A, B)

Source

impl<S: Schema, A: Selectable<S>> SingularSelectedShape<S> for (A,)

Implementors

Source

impl<S, Row, Slots> SingularSelectedShape<S> for NamedSelection<S, Row, Slots>
where S: Schema, Slots: SingularSelectedTuple<S>, Row: SelectedRowSpec<Slots::Output>,

Source

impl<S: Schema, B: Selectable<S>> SingularSelectedShape<S> for B