pub trait ModelFamily: Sealed {
type Root: ThingModel;
type Schema: Schema;
// Required method
fn iid(&self) -> &str;
}Expand description
A closed subtype family enum representing a concrete descendant closure for a root Root.
Required Associated Types
Sourcetype Root: ThingModel
type Root: ThingModel
The generated root model whose concrete descendants form this family.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".