pub trait NumericValued {
type Reduced;
}Expand description
Marker for generated attribute values whose canonical domain admits numeric reduction, carrying the canonical reduced scalar domain.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".